==> clean_bloc-1.0.0.tar.gz: lib/src/typedefs/typedefs.dart <==
import 'package:clean_network/clean_network.dart';
import 'package:flutter/material.dart';

import '../states/clean_state.dart';
import '../states/paginated_clean_state.dart';

/// default paginated bloc builder
typedef DefaultPaginatedBlocBuilder<T, E> = Widget Function(
    BuildContext, PaginatedCleanState<T, E>);

/// default bloc builder
typedef DefaultBlocBuilder<T, E> = Widget Function(
    BuildContext, CleanState<T, E>);

/// default cubit/bloc error builder
typedef CleanErrorBuilder<E> = Widget Function(BuildContext context, E error);

/// default cubit/bloc loading builder
typedef CleanLoadingBuilder = Widget Function(BuildContext context);

/// default cubit/bloc success builder
typedef CleanSuccessBuilder<T> = Widget Function(BuildContext context, T data);

/// default paginated cubit/bloc success builder
typedef PaginatedCleanSuccessBuilder<T> = Widget Function(
  BuildContext context,
  List<T> data,
  bool isLoadingMore,
  bool hasReachedMax,
);

/// Loading callback
typedef OnLoadingListener = void Function(BuildContext context);

/// Error callback
typedef OnErrorListener<E> = void Function(BuildContext context, E error);

/// Success callback
typedef OnCleanSuccessListener<T> = void Function(BuildContext context, T data);

/// Paginated Success callback
typedef OnPaginatedSuccessListener<T> = void Function(
    BuildContext context, List<T> data, bool isLoadingMore, bool hasReachedMax);

/// Error callback for cubit and bloc
typedef CleanErrorHandler<T, E> = CleanState<T, E> Function(E error);

/// Success callback for cubit and bloc
typedef CleanSuccessHandler<T, E> = CleanState<T, E> Function(T data);

/// Error callback for paginated cubit and bloc
typedef PaginatedCleanErrorHandler<T, E> = PaginatedCleanState<T, E> Function(
    E error);

/// Success callback for paginated cubit and bloc
typedef PaginatedCleanSuccessHandler<T, E> = PaginatedCleanState<T, E> Function(
    PaginatedResponse<T> response);

==> clean_bloc-1.0.1.tar.gz: lib/src/typedefs/typedefs.dart <==
import 'package:clean_network/clean_network.dart';
import 'package:flutter/material.dart';

import '../states/clean_state.dart';
import '../states/paginated_clean_state.dart';

/// default paginated bloc builder
typedef DefaultPaginatedBlocBuilder<T, E> = Widget Function(
    BuildContext, PaginatedCleanState<T, E>);

/// default bloc builder
typedef DefaultBlocBuilder<T, E> = Widget Function(
    BuildContext, CleanState<T, E>);

/// default cubit/bloc error builder
typedef CleanErrorBuilder<E> = Widget Function(BuildContext context, E error);

/// default cubit/bloc loading builder
typedef CleanLoadingBuilder = Widget Function(BuildContext context);

/// default cubit/bloc success builder
typedef CleanSuccessBuilder<T> = Widget Function(BuildContext context, T data);

/// default paginated cubit/bloc success builder
typedef PaginatedCleanSuccessBuilder<T> = Widget Function(
  BuildContext context,
  List<T> data,
  bool isLoadingMore,
);

/// Loading callback
typedef OnLoadingListener = void Function(BuildContext context);

/// Error callback
typedef OnErrorListener<E> = void Function(BuildContext context, E error);

/// Success callback
typedef OnCleanSuccessListener<T> = void Function(BuildContext context, T data);

/// Paginated Success callback
typedef OnPaginatedSuccessListener<T> = void Function(
    BuildContext context, List<T> data, bool isLoadingMore);

/// Error callback for cubit and bloc
typedef CleanErrorHandler<T, E> = CleanState<T, E> Function(E error);

/// Success callback for cubit and bloc
typedef CleanSuccessHandler<T, E> = CleanState<T, E> Function(T data);

/// Error callback for paginated cubit and bloc
typedef PaginatedCleanErrorHandler<T, E> = PaginatedCleanState<T, E> Function(
    E error);

/// Success callback for paginated cubit and bloc
typedef PaginatedCleanSuccessHandler<T, E> = PaginatedCleanState<T, E> Function(
    PaginatedResponse<T> response);
